@@ -3,6 +3,7 @@
 import math
 import numpy as np
 import torch
+from torch import nn
 from torch.optim import Optimizer
 from typing import Callable, Iterable, Optional, Tuple, Union
 
@@ -212,7 +213,6 @@ class AdamW(Optimizer):
         weight_decay: float = 0.0,
         correct_bias: bool = True,
     ):
-        require_version("torch>=1.5.0")  # add_ with alpha
         if lr < 0.0:
             raise ValueError(f"Invalid learning rate: {lr} - should be >= 0.0")
         if not 0.0 <= betas[0] < 1.0:
@@ -315,7 +315,6 @@ class AdamWGC(Optimizer):
         weight_decay: float = 0.0,
         correct_bias: bool = True,
     ):
-        require_version("torch>=1.5.0")  # add_ with alpha
         if lr < 0.0:
             raise ValueError(f"Invalid learning rate: {lr} - should be >= 0.0")
         if not 0.0 <= betas[0] < 1.0:
